==> kmyfirewall-trinity_3.5.13.2.orig.tar.xz: kmyfirewall-trinity-3.5.13.2/kmyfirewall/ruleoptionplugins/log_target_option/kmfruletargetoptioneditlog.h <==
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULETARGETOPTIONEDITLOG_H
#define KMFRULETARGETOPTIONEDITLOG_H

#include "../../core/kmfruletargetoptioneditinterface.h"

// KDE includes
#include <kparts/part.h>
#include <kparts/plugin.h>
#include <kparts/factory.h>
#include <kxmlgui.h>
class KInstance;
namespace KMF {
class IPTRule;
class KMFRuleEditTargetLog;
/**
@author Christian Hubinger
*/
class KMFRuleTargetOptionEditLog : public KMFRuleTargetOptionEditInterface {
	Q_OBJECT
  TQ_OBJECT
public:
	KMFRuleTargetOptionEditLog(TQObject *parent = 0, const char *name = 0);

	~KMFRuleTargetOptionEditLog();
	void loadRule( IPTRule* rule );	
	TQWidget* editWidget();
	const TQString& optionEditName() const;
	const TQString& description() const;
	bool setTarget( const TQString& );

private slots:
	void slotShowOverview();

private:
	KMFRuleEditTargetLog *m_edit;
	IPTRule *m_rule;
	
};



class KMFRuleTargetOptionEditLogFactory : public KLibFactory {
	Q_OBJECT
  TQ_OBJECT
public:
	KMFRuleTargetOptionEditLogFactory( TQObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleTargetOptionEditLogFactory() {
/* 		delete s_instance; */
	};
	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
	                               const TQStringList &args = TQStringList() );
	/*     static KInstance* instance(); */

/*private:
	static KInstance* s_instance;*/
};

}







#endif

==> kmyfirewall-trinity-14.0.11.tar.xz: kmyfirewall-trinity-14.0.11/kmyfirewall/ruleoptionplugins/log_target_option/kmfruletargetoptioneditlog.h <==
//
// C++ Interface: kmfruleoptioneditiip
//
// Description:
//
//
// Author: Christian Hubinger <chubinger@irrsinnig.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KMFRULETARGETOPTIONEDITLOG_H
#define KMFRULETARGETOPTIONEDITLOG_H

#include "../../core/kmfruletargetoptioneditinterface.h"

// KDE includes
#include <tdeparts/part.h>
#include <tdeparts/plugin.h>
#include <tdeparts/factory.h>
#include <kxmlgui.h>
class TDEInstance;
namespace KMF {
class IPTRule;
class KMFRuleEditTargetLog;
/**
@author Christian Hubinger
*/
class KMFRuleTargetOptionEditLog : public KMFRuleTargetOptionEditInterface {
	Q_OBJECT
  
public:
	KMFRuleTargetOptionEditLog(TQObject *parent = 0, const char *name = 0);

	~KMFRuleTargetOptionEditLog();
	void loadRule( IPTRule* rule );	
	TQWidget* editWidget();
	const TQString& optionEditName() const;
	const TQString& description() const;
	bool setTarget( const TQString& );

private slots:
	void slotShowOverview();

private:
	KMFRuleEditTargetLog *m_edit;
	IPTRule *m_rule;
	
};



class KMFRuleTargetOptionEditLogFactory : public KLibFactory {
	Q_OBJECT
  
public:
	KMFRuleTargetOptionEditLogFactory( TQObject *parent = 0, const char *name = 0 );
	virtual ~KMFRuleTargetOptionEditLogFactory() {
/* 		delete s_instance; */
	};
	virtual TQObject* createObject( TQObject* parent = 0, const char* pname = 0,
	                               const char* name = TQOBJECT_OBJECT_NAME_STRING,
	                               const TQStringList &args = TQStringList() );
	/*     static TDEInstance* instance(); */

/*private:
	static TDEInstance* s_instance;*/
};

}







#endif
